from setuptools import setup, find_packages,Extension
from Cython.Build import cythonize

extensions = [
    Extension(
        name="onepage._internal.api_logic",  # Name of the compiled module
        sources=["onepage/_internal/api_logic.pyx"],  # Source file in Python (converted to .pyx)
    ),
]

setup(
    name="onepage",
    version="0.0.5",
    packages=find_packages(),
    install_requires=["requests","typing"],
    python_requires=">=3.11",
        classifiers=[
        "Programming Language :: Python :: 3",
    ],
     ext_modules=cythonize(
         extensions,
         compiler_directives={'language_level': '3'} 
         ),
      author="OAYAW, Inc",
      author_email="hello@get1page.com",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    description="Tools for token validation and intelligent search integration.",
)
